@@ -1,11 +1,11 @@
 #' nlm_edgegradient
 #'
-#' @description Simulates an edge gradient neutral landscape model.
+#' @description Simulates an edge-gradient neutral landscape model.
 #'
 #' @param ncol [\code{numerical(1)}]\cr
-#' Number of columns for the raster.
+#' Number of columns forming the raster.
 #' @param nrow  [\code{numerical(1)}]\cr
-#' Number of rows for the raster.
+#' Number of rows forming the raster.
 #' @param resolution  [\code{numerical(1)}]\cr
 #' Resolution of the raster.
 #' @param direction [\code{numerical(1)}]\cr
@@ -18,16 +18,16 @@
 #'
 #' @details
 #' Simulates a linear gradient orientated on a specified or random direction
-#' that has a central peak. which runs perpendicular to the gradient direction.
+#' that has a central peak running perpendicular to the gradient direction.
 #'
 #' @examples
 #'
 #' # simulate random curdling
-#' (edge_gradient <- nlm_edgegradient(ncol = 100, nrow = 100, direction = 80))
+#' edge_gradient <- nlm_edgegradient(ncol = 100, nrow = 100, direction = 80)
 #'
 #' \dontrun{
 #' # visualize the NLM
-#' util_plot(edge_gradient)
+#' rasterVis::levelplot(edge_gradient, margin = FALSE, par.settings = rasterVis::viridisTheme())
 #' }
 #'
 #' @seealso \code{\link{nlm_distancegradient}},
@@ -63,7 +63,9 @@ nlm_edgegradient <- function(ncol,
   }
 
   # Create planar gradient ----
-  gradient_raster <- nlm_planargradient(ncol, nrow, direction)
+  gradient_raster <- nlm_planargradient(ncol, nrow,
+                                        resolution = resolution,
+                                        direction =  direction)
 
   # Transform to a central gradient ----
   edgegradient_raster <-
