@@ -1,39 +1,48 @@
 #' nlm_gaussianfield
 #'
 #' @description Simulates a spatially correlated random fields (Gaussian random
-#' fields) model.
+#' fields) neutral landscape model.
 #'
 #' @param ncol [\code{numerical(1)}]\cr
-#'  Number of columns for the raster.
+#'  Number of columns forming the raster.
 #' @param nrow  [\code{numerical(1)}]\cr
-#'  Number of rows for the raster.
+#'  Number of rows forming the raster.
 #' @param resolution  [\code{numerical(1)}]\cr
 #' Resolution of the raster.
 #' @param autocorr_range [\code{numerical(1)}]\cr
-#'  Maximal distance of spatial autocorrelation
+#'  Maximum range (raster units) of spatial autocorrelation.
 #' @param mag_var [\code{numerical(1)}]\cr
-#'  Magnitude of variation in the field
+#'  Magnitude of variation over the entire landscape.
 #' @param nug [\code{numerical(1)}]\cr
-#'  Small-scale variations in the field.
+#'  Magnitude of variation in the scale of \code{autocorr_range},
+#'  smaller values lead to more homogeneous landscapes.
 #' @param mean [\code{numerical(1)}]\cr
 #'  Mean value over the field.
 #' @param user_seed [\code{numerical(1)}]\cr
-#'  Set Seed for simulation
+#'  Set random seed for the simulation
 #' @param rescale [\code{numeric(1)}]\cr
 #'  If \code{TRUE} (default), the values are rescaled between 0-1.
 #'
-#' @return RasterLayer
+#' @details
+#' Gaussian random fields are a collection of random numbers on a spatially
+#' discrete set of coordinates (landscape raster). Natural sciences often apply
+#' them with spatial autocorrelation, meaning that objects which distant are more
+#' distinct from one another than they are to closer objects.
+#'
+#' @references
+#' Kéry & Royle (2016) \emph{Applied Hierarachical Modeling in Ecology}
+#' Chapter 20
 #'
 #' @examples
 #' # simulate random gaussian field
 #' gaussian_field <- nlm_gaussianfield(ncol = 90, nrow = 90,
-#'                                     autocorr_range = 10,
-#'                                     mag_var = 3,
-#'                                     nug = 0.01)
+#'                                     autocorr_range = 60,
+#'                                     mag_var = 8,
+#'                                     nug = 5)
 #'
 #' \dontrun{
 #' # visualize the NLM
-#' util_plot(gaussian_field)
+#' rasterVis::levelplot(gaussian_field, margin = FALSE, par.settings = rasterVis::viridisTheme())
 #' }
 #'
 #' @aliases nlm_gaussianfield
@@ -55,10 +64,10 @@ nlm_gaussianfield <- function(ncol,
   # Check function arguments ----
   checkmate::assert_count(ncol, positive = TRUE)
   checkmate::assert_count(nrow, positive = TRUE)
-  checkmate::assert_numeric(resolution)
+  checkmate::assert_numeric(resolution, lower = 0)
   checkmate::assert_count(autocorr_range, positive = TRUE)
-  checkmate::assert_numeric(mag_var)
-  checkmate::assert_numeric(nug)
+  checkmate::assert_numeric(mag_var, lower = 0)
+  checkmate::assert_numeric(nug, lower = 0)
   checkmate::assert_numeric(mean)
   checkmate::assert_logical(rescale)
 
@@ -68,9 +77,8 @@ nlm_gaussianfield <- function(ncol,
   RandomFields::RFoptions(spConform = FALSE)
 
   # set RF seed ----
-  if (!is.null(user_seed)) {
-    RandomFields::RFoptions(seed = user_seed)
-  }
+  RandomFields::RFoptions(seed = user_seed)
+
 
   # formulate gaussian random model
   model <- RandomFields::RMexp(var = mag_var, scale = autocorr_range) +
@@ -86,7 +94,6 @@ nlm_gaussianfield <- function(ncol,
 
   # coerce to raster
   pred_raster <- raster::raster(simu)
-  pred_raster <- pred_raster - raster::cellStats(pred_raster, "min")
 
   # specify resolution ----
   raster::extent(pred_raster) <- c(0,
